* 1. Data preparation 

clear
timer clear
timer on 1
capture clear matrix
set mem 100m
set more off

gl LMA "C:\Users\Clement\Dropbox\Waiting list\application\Blattman_2016"
use "$LMA/analysis_final", clear

set seed 2

** Globals

* Controls

gl demog_bas "bas_missing age_bas age2_bas age3_bas muslim_bas gola_bas kpelle_bas kru_bas mano_bas sapo_bas livespouse_bas children_bas disabled_dum_bas injured_dum_bas ill_dum_bas alcohol_freq_bas riskindex_bas prob_of_attend_bas"
gl capital_bas "wealth_index_bas incomemo_usd_bas_p99 savingstock_usd_bas_p99 savesmonthly_bas debtstock_usd_bas_p99"
gl ag_exp_bas "monthsagr_bas animalsyrs_bas farmyrs_bas farmsell_bas farmsize_acres_bas"
gl employment_bas "days_emp7_bas mainmining_bas mainrubber_bas mainother_bas mainnonag_bas mainagricul_bas mainfirewood_bas mainbushmeat_bas koo_bas trade_bas business_bas casualroad_bas rubber_bas mining_bas log_bas hunt_bas otherwork_bas illicitdum_bas farmint_very_bas wantagrskills_bas tenacres_bas" 
gl education_bas "educ_bas lowlit_bas highlit_bas mathscore_bas monthstrain_bas"
gl psychosocial_bas "distress_bas PTSD_bas famrel_index_bas" 	
gl aggression_bas "hostility_bas pallead_bas palneigh_bas fights_dum_bas weapons_dum_bas"
gl war_exper_bas "combatant_bas frontlineever_bas timefactmonthtot_bas_p99 violentacts_bas regret_bas viol_self_bas viol_others_bas lifebetter_bas accfam_bas accneigh_bas troublefam_bas troubletown_bas troublelive_bas"
gl mobilize_bas "jobcomm_bas relcomm_bas rel_excom_bas repcomm_bas morewar_bas fightwar_bas fightneigh_bas"
gl patience_bas "save_bas celebrate_bas eachwk_bas spendquick_bas riceseason_bas"
gl CONTROLS "$demog_bas $capital_bas $employment_bas $ag_exp_bas $education_bas $psychosocial_bas $aggression_bas $war_exper_bas $mobilize_bas $patience_bas"

* Lotteries

gl LOTTERIES "S_1-S_70"
gl LOTTERIESMORETHAN2SEATS "S_1-S_45 S_46-S_70"

* Outcomes

tab actillicit4whrs_v27d_end

// Renaming
rename agrengagednowdum_end y1
rename actillicit4whrs_v27d_end y2
rename actownagricultural4whrs7d_end y3
rename economic_index1_end y4
rename mobil_ic_mod_end  y5
rename rel_excoms_end y6
rename rel_commanders_end y7
rename peergroupindexstd_end y8
rename socialsupport_indexstd_end y9
rename famrelationship_indexstd_end y10

// Outcomes list
gl OUTCOMES "y1 y2 y3 y4 y5 y6 y7 y8 y9 y10"

*renaming instruments, treatment, and lottery variables 

rename assigned_final Z
rename assigned_initial Z2
rename treated_1d d
drop lottery
rename stratum_min6 lottery

*keeping variables necessary for analysis

keep d Z Z2 $CONTROLS $LOTTERIES $OUTCOMES lottery sample female

* All lotteries have at least 2 seats?

*Restricting sample

keep if sample==1 & female==0

*Unique lottery identifier, with the two lotteries with less than two seats at the end Lottery indicator

//2 lotteries with less than 2 seats

egen lottery_number=group(lottery)

gen Z_d=Z*d
bys lottery: egen s_k=total(Z_d) 
tab lottery_number if s_k<2
gen less_2_seats=(s_k<2)
tab less_2_seats

replace lottery_number=69 if lottery_number==23 
replace lottery_number=70 if lottery_number==44
replace lottery_number=23 if lottery_number==67 
replace lottery_number=44 if lottery_number==68
replace lottery_number=67 if lottery_number==69 
replace lottery_number=68 if lottery_number==70

* 2. Estimating the effect of the training on applicants' outcomes */ 

qui{

*EO FE

forvalue i=1/10{
reg  d $LOTTERIES $CONTROLS Z if y`i'!=.
scalar fs=_b[Z]
reg  y`i' $LOTTERIES $CONTROLS Z 
scalar itt=_b[Z]
scalar late_y`i'_EO=itt/fs
scalar N`i'_3=e(N)
// se EO
sum d if y`i'!=.
scalar N_bar=r(N)/68
reg d $CONTROLS if y`i'!=.
predict eps_d, residuals
reg y`i' $CONTROLS 
predict eps_y, residuals
gen lambda_EO_`i'=.
scalar fs_lin=0
forvalue j=1/68{
sum Z if y`i'!=.&lottery_number==`j'
scalar p_k=r(N)*r(mean)*(1-r(mean))
capture: reg eps_d Z if y`i'!=.&lottery_number==`j'
capture: scalar fs_k=_b[Z]
capture: reg eps_y Z if y`i'!=.&lottery_number==`j'
capture: scalar rf_k=_b[Z]
capture: replace lambda_EO_`i'=p_k*(rf_k-fs_k*late_y`i'_EO) in `j'
scalar fs_lin=fs_lin+1/68*fs_k*p_k
}
replace lambda_EO_`i'=lambda_EO_`i'/fs_lin
sum lambda_EO_`i'
scalar se_EO_`i'=r(sd)/sqrt(r(N)-1)
drop eps_d eps_y
}

* DREO

*preserve

drop if less_2_seats==1

// weights

gen w_re=1 
foreach var of varlist $LOTTERIESMORETHAN2SEATS{
sum Z if Z==1&(d==1)&`var'==1
di (r(N)-1)/r(N)
replace w_re=(r(N)-1)/r(N) if Z==1&(d==1)&`var'==1  
}
gen Z1_w_re=Z*w_re
gen Z0_w_re=(1-Z)*w_re
egen num1=total(Z1_w_re)
egen denom1=total(w_re)
egen num2=total(w_re), by(lottery)
egen denom2=total(Z1_w_re), by(lottery)
egen num3=total(Z0_w_re)
egen denom3=total(w_re)
egen num4=total(w_re), by(lottery)
egen denom4=total(Z0_w_re), by(lottery)
gen count=1
egen taille_lottery=total(count), by(lottery)
gen poids=w_re*(Z*num1/denom1*num2/denom2+(1-Z)*num3/denom3*num4/denom4)*taille_lottery/(taille_lottery-1)

// DREO 

forvalue i=1/10{
reg  d $CONTROLS Z [pw=poids] if y`i'!=.
scalar fs=_b[Z]
reg  y`i' $CONTROLS Z [pw=poids] 
scalar itt=_b[Z]
scalar late_y`i'_DREO=itt/fs
scalar N`i'_4=e(N)
// se DREO
sum d if y`i'!=.
scalar N_bar=r(N)/66
reg d $CONTROLS [pw=poids] if y`i'!=.
predict eps_d, residuals
reg y`i' $CONTROLS [pw=poids] 
predict eps_y, residuals
gen lambda_DREO_`i'=.
forvalue j=1/66 {
sum d if y`i'!=.&lottery_number==`j'
scalar p_k=r(N)/N_bar
capture: reg eps_d Z [pw=w_re] if y`i'!=.&lottery_number==`j'
capture: scalar fs_k=_b[Z]
capture: reg eps_y Z [pw=w_re] if y`i'!=.&lottery_number==`j'
capture: scalar rf_k=_b[Z]
capture: replace lambda_DREO_`i'=p_k*1/fs*(rf_k-fs_k*late_y`i'_DREO) in `j'
}
sum lambda_DREO_`i'
scalar se_DREO_`i'=r(sd)/sqrt(r(N)-1)
drop eps_d eps_y
}

// Diff EO DREO

forvalue i=1/10{
gen diff`i'=lambda_DREO_`i'-lambda_EO_`i'
noisily sum diff`i'
scalar p`i'=2*(1-normal(abs((late_y`i'_EO-late_y`i'_DREO)/(r(sd)/sqrt(r(N)-1)))))
noisily di p`i'
} 

// E(Y0|T)-E(Y0|NT)

forvalue i=1/10{
reg y`i' Z [pw=poids] if d==0 
scalar num=_b[Z]
reg d Z [pw=poids] if y`i'!=.
scalar deltay0_`i'=-num/_b[Z]*(1-_b[_cons])
}

*restore

}

* Table

di late_y1_EO,se_EO_1,late_y1_DREO,se_DREO_1,p1,deltay0_1
di late_y2_EO,se_EO_2,late_y2_DREO,se_DREO_2,p2,deltay0_2
di late_y3_EO,se_EO_3,late_y3_DREO,se_DREO_3,p3,deltay0_3
di late_y4_EO,se_EO_4,late_y4_DREO,se_DREO_4,p4,deltay0_4
di late_y5_EO,se_EO_5,late_y5_DREO,se_DREO_5,p5,deltay0_5
di late_y6_EO,se_EO_6,late_y6_DREO,se_DREO_6,p6,deltay0_6
di late_y7_EO,se_EO_7,late_y7_DREO,se_DREO_7,p7,deltay0_7
di late_y8_EO,se_EO_8,late_y8_DREO,se_DREO_8,p8,deltay0_8
di late_y9_EO,se_EO_9,late_y9_DREO,se_DREO_9,p9,deltay0_9
di late_y10_EO,se_EO_10,late_y10_DREO,se_DREO_10,p10,deltay0_10
