////////////////////////////// This do file contains some of the simulations presented in the Web appendix of the paper /////////////////////

clear all
set more off
set matsize 2100
*global CHEMIN="U:\waiting list"
global CHEMIN="C:\Users\Clement\Dropbox\Waiting list"
global TIME=substr("${S_TIME}",1,2)+"_"+substr("${S_TIME}",4,2)
capture log close
log using "$CHEMIN\log\simulations ${S_DATE} ${TIME}.log", replace
global reps=500

////// 1. Comparison DREO and optimal estimator of LATE among all 2SLS estimator using a function of applicants' random numbers as instrument

 // 1.a) Program
 
capture prog drop simu
prog define simu, rclass

* *** Initiate base
global nbobs=${nbstrates}*${taillestrate}
clear
set obs ${nbobs}

* **** Strata
gen id=_n
gen STRATE=int((id-1)/${taillestrate}) + 1

* **** Accepters

gen modulus=mod(id-1,${taillestrate})
gen Comp=(modulus<=$compliers -1)
gen AT=(modulus>=$compliers&modulus<$compliers+$alwaystakers)
gen NT=1-Comp-AT
gen C=Comp+AT
sum Comp AT C NT

* *** Instruments

* Random waiting lists
gen u=uniform()
egen RANG=rank(u), by (STRATE)

* T (rank of last student admitted)
forvalue a=`=$seats'/`=$seats+$taillestrate-$accepters'{
gen C`a'=C*(RANG<=`a')
egen SUM_C`a'=sum(C`a'), by(STRATE)
}
gen T=0 
forvalue a=`=$seats'/`=$seats+$taillestrate-$accepters'{
replace T=`a' if T==0 & SUM_C`a'==$seats
}

* Initial offer
gen ZI=(RANG<=$seats)

* Ever offer instrument
gen ZE=(RANG<=T)

* Optimal instrument (without always takers)

gen Z_opt=0
replace Z_opt=$accepters/$taillestrate if RANG<=$seats
forvalue r=`=$seats+1'/`=$seats+$taillestrate-$accepters'{
scalar Z_opt_`r'=0
global init_loop=max(1,`r'-($taillestrate-$accepters))
forvalue k=`=$init_loop'/`=$seats'{
scalar Z_opt_`r'=Z_opt_`r'+comb(`r'-1,`k'-1)*comb($taillestrate-`r',$accepters-`k')/comb($taillestrate,$accepters)
}
replace Z_opt=Z_opt_`r' if RANG==`r'
}
bys STRATE: sum Z_opt
di $seats/$taillestrate

sort STRATE RANG 
order STRATE RANG C ZI ZE
* br STRATE RANG C ZI ZE

* *** Treatment
gen D=ZE*C+(1-ZE)*AT

* *** Outcome variables

* Potential outcomes
gen y0=invnorm(uniform())+$delta_NT*NT+$delta_AT*AT
gen y1=y0+0.2

* Observed outcome
gen Y=y0*(1-D)+y1*D

* *** Weights

* wRE: reweighting to take into account one accepter in excess with ZI
gen wRE=(ZE*D*($seats -1)/$seats + (1-ZE)+ZE*(1-D))

* wDRE: weights to take into account varying size of control groups across strata
egen swRE=total(wRE)
egen swREk=total(wRE), by(STRATE)

gen wREZ=wRE*ZE
egen swREZ=total(wREZ)
egen swREZk=total(wREZ), by(STRATE)

gen wRE1mZ=wRE*(1-ZE)
egen swRE1mZ=total(wRE1mZ)
egen swRE1mZk=total(wRE1mZ), by(STRATE)

gen wDRE=wRE * ( ZE*(swREZ/swRE)*(swREk/swREZk) + (1-ZE)*(swRE1mZ/swRE)*(swREk/swRE1mZk) )*${taillestrate}/(${taillestrate}-1)
drop sw*

* *** 2SLS

* Doubly reweighted
	ivregress 2sls Y (D=ZE) [pw=wDR], r 
	return scalar tslsDRE=_b[D]
	return scalar coverageDRE=(0.2>=_b[D]-1.96*_se[D]&0.2<=_b[D]+1.96*_se[D])
* Optimal
	ivregress 2sls Y (D=Z_opt), r
	return scalar tslsOPT=_b[D]
	return scalar coverageOPT=(0.2>=_b[D]-1.96*_se[D]&0.2<=_b[D]+1.96*_se[D])

end

// 1.b) Simulation

set seed 2

* DGP de base, tres proche de la moyenne observee dans les applis
scalar DGP1=1
scalar nbstrates1=120
scalar taillestrate1=40
scalar compliers1=30
scalar alwaystakers1=0
scalar accepters1=30
scalar seats1=20
scalar delta_AT1=0
scalar delta_NT1=0.4

forvalue i=1/1{
global DGP=DGP`i'
global nbstrates=nbstrates`i'
global taillestrate=taillestrate`i'
global compliers=compliers`i'
global alwaystakers=alwaystakers`i'
global accepters=accepters`i'
global seats=seats`i'
global delta_AT=delta_AT`i'
global delta_NT=delta_NT`i'
simulate    tslsOPT=r(tslsOPT) ///
			coverageOPT=r(coverageOPT) ///
			tslsDRE=r(tslsDRE) ///
			coverageDRE=r(coverageDRE), saving("${CHEMIN}\log\simulation - comparison estimateur optimal - DGP ${DGP} - ${reps} reps - ${nbstrates} strates - ${S_DATE}.dta", replace)reps(${reps}): simu
use "${CHEMIN}\log\simulation - comparison estimateur optimal - DGP ${DGP} - ${reps} reps - ${nbstrates} strates - ${S_DATE}.dta", clear
save "${CHEMIN}\log\simulation - comparison estimateur optimal - DGP ${DGP} - ${reps} reps.dta", replace
}

set more off
forvalue dgp=1/1 {
global DGP=`dgp'
global nbstrates=nbstrates`dgp'
global taillestrate=taillestrate`dgp'
global compliers=compliers`dgp'
global alwaystakers=alwaystakers`dgp'
global accepters=accepters`dgp'
global seats=seats`dgp'
global delta_AT=delta_AT`dgp'
global delta_NT=delta_NT`dgp'

use "${CHEMIN}\log\simulation - comparison estimateur optimal - DGP ${DGP} - ${reps} reps.dta", replace

foreach suf in DRE OPT {

* 2SLS
qui sum tsls`suf', detail
sca m`suf'=r(mean)
sca med`suf'=r(p50)
sca se`suf'=r(sd)
sca rmse`suf'=((m`suf' - 0.2)^2 + se`suf'^2)^.5
qui sum coverage`suf', detail
sca coverage`suf'=r(mean)
matrix Mtsls`suf'= m`suf',  se`suf', coverage`suf'
}
matrix Mtsls = MtslsDRE \ MtslsOPT

matrix M= Mtsls
matrix list M

outtable using "${CHEMIN}\log\comparison estimateur optimal - DGP ${DGP} - ${reps} reps" , mat(M) replace format(%9.3f)

capture log close
log using "${CHEMIN}\log\comparison estimateur optimal - DGP ${DGP} - ${reps} reps.log", replace
matrix list M
log close

}

use "${CHEMIN}\log\simulation - comparison estimateur optimal - DGP ${DGP} - ${reps} reps.dta", replace

sum tslsDRE
scalar se1=r(sd)
sum tslsOPT
scalar se2=r(sd)
scalar diff=se1-se2

matrix A=0,0,0

qui{
forvalue i=1/200{
preserve
bsample
sum tslsDRE
scalar se1_bs=r(sd)
sum tslsOPT
scalar se2_bs=r(sd)
scalar diff_bs=se1_bs-se2_bs
matrix A=A\se1_bs,se2_bs,diff_bs
restore
}
}
preserve
set more off
drop _all
svmat A
drop if _n==1
sum A1 A2
di se1, se2
sum A3
di diff
di diff/r(sd)


